<?php
/* $Id: russian-utf-8.inc.php,v 2.123.2.1 2006/02/17 12:43:01 lem9 Exp $ */

/**
 * Translated by Gosha Sakovich <gt2 at users.sourceforge.net>
 *               Artyom Rabzonov <tyomych at gmx.net>
 *               Nicolay Zakharov <info at melody.org.ru> 16-Dec-2002
 *               (nobody) 2004-09-18
 */

$charset = 'utf-8';
$allow_recoding = TRUE;
$text_dir = 'ltr';
$left_font_family = 'sans-serif';
$right_font_family = 'sans-serif';
$number_thousands_separator = ',';
$number_decimal_separator = '.';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
//$byteUnits = array('Байт', 'кБ', 'МБ', 'ГБ');
$byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Вс', 'Пн', 'Вт', 'Ср', 'Чт', 'Пт', 'Сб');
$month = array('Янв', 'Фев', 'Мар', 'Апр', 'Май', 'Июн', 'Июл', 'Авг', 'Сен', 'Окт', 'Ноя', 'Дек');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%B %d %Y г., %H:%M';
$timespanfmt = '%s дней, %s часов, %s минут и %s секунд';

$strAPrimaryKey = 'Был добавлен первичный ключ к %s';
$strAbortedClients = 'Отменены';
$strAbsolutePathToDocSqlDir = 'Введите абсолютный путь на сервере к директории docSQL, пожалуйста';
$strAccessDenied = 'В доступе отказано';
$strAccessDeniedExplanation = 'phpMyAdmin попытался соединиться с сервером MySQL, но сервер отверг соединение. Проверьте имя хоста, пользователя и пароль в config.inc.php.';
$strAction = 'Действие';
$strAddAutoIncrement = 'Добавить значение AUTO_INCREMENT';
$strAddConstraints = 'Добавить ограничения';
$strAddDeleteColumn = 'Добавить/удалить столбец критерия';
$strAddDeleteRow = 'Добавить/удалить ряд критерия';
$strAddDropDatabase = 'Добавить DROP DATABASE';
$strAddHeaderComment = 'Добавить частные сомментарии к header (\\n разбивает строки)';
$strAddIfNotExists = 'Добавить IF NOT EXISTS';
$strAddIntoComments = 'Добавить в комментарии';
$strAddNewField = 'Добавить новое поле';
$strAddPrivilegesOnDb = 'Добавить привилегии на следующую базу';
$strAddPrivilegesOnTbl = ' Добавить привилегии на следующую таблицу';
$strAddSearchConditions = 'Добавить условия поиска (тело для условия "where"):';
$strAddToIndex = 'Добавить к индексу&nbsp;%s&nbsp;колонку(и)';
$strAddUser = 'Добавить нового пользователя';
$strAddUserMessage = 'Был добавлен новый пользователь.';
$strAddedColumnComment = 'Добавленный комментарий для столбца';
$strAddedColumnRelation = 'Добавленная связь для столбца';
$strAdministration = 'Администрирование';
$strAffectedRows = 'Затронутые ряды:';
$strAfter = 'После %s';
$strAfterInsertBack = 'Возврат';
$strAfterInsertNewInsert = 'Вставить новую запись';
$strAfterInsertSame = 'Возвратиться к этой странице';
$strAll = 'Все';
$strAllTableSameWidth = 'показать все таблицы с такой шириной?';
$strAlterOrderBy = 'Изменить порядок таблицы';
$strAnIndex = 'Был добавлен индекс для %s';
$strAnalyzeTable = 'Анализ таблицы';
$strAnd = 'И';
$strAny = 'Любой';
$strAnyHost = 'Любой хост';
$strAnyUser = 'Любой пользователь';
$strArabic = 'Арабский';
$strArmenian = 'Армянский';
$strAscending = 'По возрастанию';
$strAtBeginningOfTable = 'В начало таблицы';
$strAtEndOfTable = 'В конец таблицы';
$strAttr = 'Атрибуты';
$strAutodetect = 'Автодетект';
$strAutomaticLayout = 'Автоматическая раскладка';

$strBack = 'Назад';
$strBaltic = 'Балтийский';
$strBeginCut = 'BEGIN CUT';
$strBeginRaw = 'BEGIN RAW';
$strBinary = ' Двоичный ';
$strBinaryDoNotEdit = ' Двоичные данные - не редактируются ';
$strBookmarkAllUsers = 'Дать каждому пользователю использовать эту закладку';
$strBookmarkDeleted = 'Закладка была удалена.';
$strBookmarkLabel = 'Метка';
$strBookmarkQuery = 'Закладка на SQL-запрос';
$strBookmarkThis = 'Закладка на данный SQL-запрос';
$strBookmarkView = 'Только просмотр';
$strBrowse = 'Обзор';
$strBrowseForeignValues = 'Browse foreign values';
$strBulgarian = 'Болгарский';
$strBzError = 'phpMyAdmin не может сжать дамп из-за проблем с Bz2 extension в текущей версии PHP. Строго рекомендуется установить переменной <code>$cfg[\'BZipDump\']</code> в Вашем конфигурационном файле phpMyAdmin значение <code>FALSE</code>. Если Вы хотите использовать Bz2-компрессию, Вам необходимо обновить PHP. Смотрите PHP bug report %s для более подробной информации.';
$strBzip = 'архивировать в bzip';

$strCSVOptions = 'Опции CSV';
$strCalendar = 'Календарь';
$strCannotLogin = 'Невозможно войти в MySQL';
$strCantLoad = 'не могу загрузить расширение %s,<br />проверьте конфигурацию PHP, пожалуйста';
$strCantLoadRecodeIconv = 'Не могу загрузить iconv или recode, необходимые для перекодирования символов. Проверьте php-конфигурацию и разрешите их использование или запретите перекодирование символов в phpMyAdmin.';
$strCantRenameIdxToPrimary = 'Невозможно переименовать индекс в PRIMARY!';
$strCantUseRecodeIconv = 'Не могу использовать iconv функции: ни libiconv, ни recode_string, пока не будут загружены extension reports. Проверьте php-конфигурацию.';
$strCardinality = 'Количество элементов';
$strCaseInsensitive = 'нечувствительный к регистру';
$strCaseSensitive = 'чувствительный к регистру ';
$strCentralEuropean = 'Центрально-Европейский';
$strChange = 'Изменить';
$strChangeCopyMode = 'Создать нового пользователя с такими же привилегиями и ...';
$strChangeCopyModeCopy = '... сохранить старого.';
$strChangeCopyModeDeleteAndReload = ' ... удалить старого из таблиц пользователей и перезагрузить привилегии.';
$strChangeCopyModeJustDelete = ' ... удалить старого из таблиц пользователей.';
$strChangeCopyModeRevoke = ' ... отменить все активные привилегии старого и затем удалить его.';
$strChangeCopyUser = 'Изменить информацию логина/ Копировать пользователя';
$strChangeDisplay = 'Выберите поле для отображения';
$strChangePassword = 'Изменить пароль';
$strCharset = 'Кодировка';
$strCharsetOfFile = 'Кодировка файла:';
$strCharsets = 'Кодировки';
$strCharsetsAndCollations = 'Кодировки и сравнения';
$strCheckAll = 'Отметить все';
$strCheckOverhead = 'Отметить требующие оптимизации';
$strCheckPrivs = 'Проверить привилегии';
$strCheckPrivsLong = 'Проверить привилегии для базы &quot;%s&quot;.';
$strCheckTable = 'Проверить таблицу';
$strChoosePage = 'Выберите страницу для редактирования';
$strColComFeat = 'Показать комментария столбцов';
$strCollation = 'Сравнение';
$strColumnNames = 'Названия колонок';
$strColumnPrivileges = 'Привилегии, специфичные для столбца';
$strCommand = 'Команда';
$strComments = 'Комментарии';
$strCommentsForTable = 'Комментарии к таблице';
$strCompleteInserts = 'Полная вставка';
$strCompression = 'Сжатие';
$strConfigFileError = 'phpMyAdmin не может прочитать данные из конфигурационного файла!  <br />Возможная причина - синтаксическая ошибка.<br />Вызовите этот файл (config.inc.php) непосредственно из браузера. Если будут сообщения об ошибках - исправьте их. Если пустая страница - все в порядке';
$strConfigureTableCoord = 'Измените координаты таблицы %s';
$strConnectionError = 'Соединение невозможно: неверные устоновки.';
$strConnections = 'Соединения';
$strConstraintsForDumped = 'Constraints for dumped tables';
$strConstraintsForTable = 'Constraints for table';
$strCookiesRequired = 'Cookies должны быть включены после этого места.';
$strCopyTable = 'Скопировать таблицу в (база данных<b>.</b>таблица):';
$strCopyTableOK = 'Таблица %s была скопирована в %s.';
$strCopyTableSameNames = ' Не могу скопировать таблицу саму в себя !';
$strCouldNotKill = 'phpMyAdmin не смог удалить thread %s. Возможно, он уже закрыт.';
$strCreate = 'Создать';
$strCreateIndex = 'Создать индекс на&nbsp;%s&nbsp;колонках';
$strCreateIndexTopic = 'Создать новый индекс';
$strCreateNewDatabase = 'Создать новую БД';
$strCreateNewTable = 'Создать новую таблицу в БД %s';
$strCreatePage = 'Создать новую страницу';
$strCreatePdfFeat = 'Создание PDF-схемы';
$strCreationDates = 'Создание/Обновление/Проверка дат';
$strCriteria = 'Критерий';
$strCroatian = 'Хорватский';
$strCyrillic = 'Кириллический';
$strCzech = 'Чешский';
$strCzechSlovak = 'Чешский';

$strDBComment = 'Комментарий БД: ';
$strDBGContext = 'Контекст';
$strDBGContextID = 'Контекст ID';
$strDBGHits = 'Hits';
$strDBGLine = 'Line';
$strDBGMaxTimeMs = 'Максимальное время, ms';
$strDBGMinTimeMs = 'Минимальное время, ms';
$strDBGModule = 'Модуль';
$strDBGTimePerHitMs = 'Time/Hit, ms';
$strDBGTotalTimeMs = 'Итоговое время, ms';
$strDBRename = 'Переименовать базу данных в';
$strDanish = 'Датский';
$strData = 'Данные';
$strDataDict = 'Словарь данных';
$strDataOnly = 'Только данные';
$strDatabase = 'БД';
$strDatabaseEmpty = 'Имя базы данных не указанно!';
$strDatabaseExportOptions = 'Опции экспорта БД';
$strDatabaseHasBeenDropped = 'База данных %s была удалена.';
$strDatabaseNoTable = 'Эта БД не содержит таблиц!';
$strDatabases = 'Базы Данных';
$strDatabasesDropped = '%s БД были успешно удалены.';
$strDatabasesStats = 'Статистика баз данных';
$strDatabasesStatsDisable = 'Отключить статистику';
$strDatabasesStatsEnable = 'Включить статистику';
$strDatabasesStatsHeavyTraffic = 'Замечание: Включение статистики базы данных может спровоцировать большой трафик между веб-сервером и сервером MySQL.';
$strDbPrivileges = ' Привилегии, специфичные для базы данных';
$strDbSpecific = 'специфично для БД';
$strDefault = 'По умолчанию';
$strDefaultValueHelp = 'Для значений по умолчанию просто введите единственное значение без экранирования и квотирования, используя этот формат: a';
$strDefragment = 'Дефрагментировать таблицу';
$strDelOld = 'В текущей странице есть ссылки на таблицы, котрые больше не существуют. Вы хотите удалить эти ссылки?';
$strDelayedInserts = 'Использовать запаздывающие вставки';
$strDelete = 'Удалить';
$strDeleteAndFlush = 'Удалить всех пользователей и перезагрузить привилегии.';
$strDeleteAndFlushDescr = 'Это лучший способ, но перезагрузка привилегий может занять некоторое время.';
$strDeleted = 'Ряд был удален';
$strDeletedRows = 'Следующие ряды были удалены:';
$strDeleting = 'Удаление %s';
$strDescending = 'По убыванию';
$strDescription = 'Описание';
$strDictionary = 'словарь';
$strDisableForeignChecks = 'Выключить проверку инородных ключей';
$strDisabled = 'Недоступно';
$strDisplayFeat = 'Показать дополнительные возможности';
$strDisplayOrder = 'Порядок просмотра:';
$strDisplayPDF = 'Показать PDF-схему';
$strDoAQuery = 'Выполнить "запрос по примеру" (символ подстановки: "%")';
$strDoYouReally = 'Вы действительно желаете ';
$strDocu = 'Документация';
$strDrop = 'Уничтожить';
$strDropDatabaseStrongWarning = 'Вы уверенны что хотите уничтожить всю базу данных?';
$strDropUsersDb = 'Удалить базы, которые имеют такие же имена как и пользователи.';
$strDumpSaved = 'Дамп сохранён в файл %s.';
$strDumpXRows = 'Дамп %s записей, начиная с %s.';
$strDumpingData = 'Дамп данных таблицы';
$strDynamic = 'динамический';

$strEdit = 'Правка';
$strEditPDFPages = 'Изменить PDF-страницы';
$strEditPrivileges = 'Редактирование привилегий';
$strEffective = 'Эффективность';
$strEmpty = 'Очистить';
$strEmptyResultSet = 'MySQL вернула пустой результат (т.е. ноль рядов).';
$strEnabled = 'Доступно';
$strEncloseInTransaction = 'Экспортировать при переводе';
$strEnd = 'Конец';
$strEndCut = 'END CUT';
$strEndRaw = 'END RAW';
$strEnglish = 'Английский';
$strEnglishPrivileges = ' Примечание: привилегии MySQL задаются по-английски ';
$strError = 'Ошибка';
$strEstonian = 'Эстонский';
$strExcelEdition = 'Excel-публикация';
$strExcelOptions = 'Опции Excel';
$strExecuteBookmarked = 'Выпонить отмеченный запрос';
$strExplain = 'Описать SQL';
$strExport = 'Экспорт';
$strExtendedInserts = 'Расширенные вставки';
$strExtra = 'Дополнительно';

$strFailedAttempts = 'Неудачные попытки';
$strField = 'Поле';
$strFieldHasBeenDropped = 'Поле %s было удалено';
$strFields = 'Поля';
$strFieldsEmpty = ' Пустой счетчик полей! ';
$strFieldsEnclosedBy = 'Поля заключены в';
$strFieldsEscapedBy = 'Поля экранируются';
$strFieldsTerminatedBy = 'Поля разделены';
$strFileAlreadyExists = 'Файл %s уже существует на сервере, измените имя или воспользуйтесь опцией перезаписи.';
$strFileCouldNotBeRead = 'Файл не может быть прочитан';
$strFileNameTemplate = 'Шаблон имени файла';
$strFileNameTemplateRemember = 'запомнить шаблон';
$strFixed = 'фиксированный';
$strFlushPrivilegesNote = 'Замечание: phpMyAdmin получает пользовательские привилегии прямо из таблиц привилегий MySQL. Содержимое этих таблиц может отличаться от от привилегий, которые использует сервер, если изменения были внесены вручную. В этом случае вы должны %sперезагрузить привилегии%s перед продолжением работы.';
$strFlushTable = 'Сбросить кэш таблицы ("FLUSH")';
$strFormEmpty = 'Требуется значение для формы!';
$strFormat = 'Формат';
$strFullText = 'Полные тексты';
$strFunction = 'Функция';

$strGenBy = 'Созданный';
$strGenTime = 'Время создания';
$strGeneralRelationFeat = 'Основные возможности связей';
$strGeorgian = 'Грузинский';
$strGerman = 'Немецкий';
$strGlobal = 'global';
$strGlobalPrivileges = 'Глобальные привилегии';
$strGlobalValue = 'Глобальное значение';
$strGo = 'Пошел';
$strGrantOption = 'Предоставлять';
$strGreek = 'Греческий';
$strGzip = 'архивировать в gzip';

$strHasBeenAltered = 'была изменена.';
$strHasBeenCreated = 'была создана.';
$strHaveToShow = 'Вы должны выбрать не менее одной колонки для отображения';
$strHebrew = 'Иврит';
$strHexForBinary = 'Использовать шестнадцатиричные (hexadecimal) бинарные поля';
$strHome = 'К началу';
$strHomepageOfficial = 'Официальная страница phpMyAdmin';
$strHost = 'Хост';
$strHostEmpty = 'Пустое имя хоста!';
$strHungarian = 'Венгерский';

$strIcelandic = 'Исландский';
$strId = 'ID';
$strIdxFulltext = 'ПолнТекст';
$strIgnore = 'Игнорировать';
$strIgnoreInserts = 'Игнорировать вставки';
$strIgnoringFile = 'Игнорирую файл %s';
$strImportDocSQL = 'Импорт docSQL файлов';
$strImportFiles = 'Импорт файлов';
$strInUse = 'используется';
$strIndex = 'Индекс';
$strIndexHasBeenDropped = 'Индекс %s был удален';
$strIndexName = 'Имя индекса&nbsp;:';
$strIndexType = 'Тип индекса&nbsp;:';
$strIndexes = 'Индексы';
$strInnodbStat = 'InnoDB статус';
$strInsecureMySQL = 'Ваш конфигурационный файл содержит настройки (пользователь root без пароля), которые относятся к привилегированному пользователю MySQL (по умолчанию). Ваш MySQL сервер запущен с этими настройками по умолчанию, открытый для вторжений, поэтому Вам настоятельно рекомендуется устранить эту дыру в безопасности.';
$strInsert = 'Вставить';
$strInsertAsNewRow = 'Вставить новый ряд';
$strInsertNewRow = 'Вставить новый ряд';
$strInsertedRowId = 'Вставить id ряда:';
$strInsertedRows = 'Добавлены ряды:';
$strInternalNotNecessary = '* Внутренняя связь не обязательна, когда она также существует в InnoDB.';
$strInternalRelations = 'Внутренние связи';

$strJapanese = 'Японский';
$strJumpToDB = 'Перейти к базе &quot;%s&quot;.';
$strJustDelete = 'Просто удалить пользователей из таблиц привилкгий.';
$strJustDeleteDescr = '&quot;Удалённые&quot; пользователи всё ещё смогут работать с с ервером как обычно до перезагрузки привилегий.';

$strKeepPass = 'Не менять пароль';
$strKeyname = 'Имя ключа';
$strKill = 'Убить';
$strKorean = 'Корейский';

$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Опции LaTeX';
$strLandscape = 'Ландшафт';
$strLatexCaption = 'Заголовок таблицы';
$strLatexContent = 'Содержимое таблицы __TABLE__';
$strLatexContinued = '(продолжено)';
$strLatexContinuedCaption = 'Продолженный заголовок таблицы';
$strLatexIncludeCaption = 'Включить заголовок таблицы';
$strLatexLabel = 'Label key';
$strLatexStructure = 'Структура таблицы __TABLE__';
$strLatvian = 'Латвийский';
$strLengthSet = 'Длины/Значения*';
$strLimitNumRows = 'записей на страницу';
$strLinesTerminatedBy = 'Строки разделены';
$strLinkNotFound = 'Связь не найдена';
$strLinksTo = 'Связь с';
$strLithuanian = 'Латвийский';
$strLocalhost = 'Local';
$strLocationTextfile = 'Месторасположение текстового файла';
$strLogPassword = 'Пароль:';
$strLogServer = 'Сервер';
$strLogUsername = 'Пользователь:';
$strLogin = 'Вход в систему';
$strLoginInformation = 'Информация логина';
$strLogout = 'Выйти из системы';

$strMIMETypesForTable = 'MIME-типы таблицы';
$strMIME_MIMEtype = 'MIME-тип';
$strMIME_available_mime = 'Доступные MIME-типы';
$strMIME_available_transform = 'Доступные трансформации';
$strMIME_description = 'Описание';
$strMIME_nodescription = 'Нет доступных описаний для этой трансформации.<br />Пожалуйста, спросите автора что делает %s.';
$strMIME_transformation = 'Трансформация браузера';
$strMIME_transformation_note = 'Для списка доступных опций трансформации и трансформаций их MIME-типов кликните на %sописание трансформаций%s';
$strMIME_transformation_options = 'Опции трансформации';
$strMIME_transformation_options_note = 'Пожалуйсиа, введите значения для трансформации, используя этот формат: \'a\',\'b\',\'c\'...<br />Если вам нужно поставить бэкслэш("\") или кавычку("\'"), экранируйте их (например \'\\\\xyz\' or \'a\\\'b\').';
$strMIME_without = 'MIME-типы, выделенные курсивом, не имеют отдельной функции трансформации';
$strMaximumSize = 'Максимальный размер: %s%s';
$strModifications = 'Модификации были сохранены';
$strModify = 'Изменить';
$strModifyIndexTopic = 'Изменить индекс';
$strMoveTable = 'Переместить таблицы в (база данных<b>.</b>таблица):';
$strMoveTableOK = 'Таблица %s была перемещена в %s.';
$strMoveTableSameNames = 'Не могу переместить таблицу саму в себя!';
$strMultilingual = 'многоязычный';
$strMySQLCharset = 'MySQL-кодировка';
$strMySQLConnectionCollation = 'Сопоставление соединения с MySQL';
$strMySQLSaid = 'Ответ MySQL: ';
$strMySQLShowProcess = 'Показать процессы';
$strMySQLShowStatus = 'Показать состояние MySQL';
$strMySQLShowVars = 'Показать системные переменные MySQL';

$strName = 'Имя';
$strNext = 'Далее';
$strNo = 'Нет';
$strNoDatabases = 'БД отсутствуют';
$strNoDatabasesSelected = 'Ни одна БД не выбрана.';
$strNoDescription = 'нет описания';
$strNoDropDatabases = 'Команда "Удалить БД" отключена.';
$strNoExplain = 'Прекратить описание SQL';
$strNoFrames = 'Для работы phpMyAdmin нужен браузер с поддержкой <b>фреймов</b>.';
$strNoIndex = 'Индекс не определен!';
$strNoIndexPartsDefined = 'Части индекса не определены!';
$strNoModification = 'Нет изменений';
$strNoOptions = 'В этом формате нет опций';
$strNoPassword = 'Без пароля';
$strNoPermission = 'Веб-серверу не хватает прав для сохранения файла %s.';
$strNoPhp = 'без PHP-кода';
$strNoPrivileges = 'Без привилегий';
$strNoRights = 'Вы не имеете достаточно прав для этого!';
$strNoRowsSelected = 'Строка таблицы не выбрана';
$strNoSpace = 'Не хватает дискового пространства для сохранения файла %s.';
$strNoTablesFound = 'В БД не обнаружено таблиц.';
$strNoUsersFound = 'Не найден пользователь.';
$strNoValidateSQL = 'Не проверять SQL';
$strNone = 'Нет';
$strNotNumber = 'Это не число!';
$strNotOK = 'Не готово';
$strNotSet = 'Таблица <b>%s</b> не найдена';
$strNull = 'Ноль';
$strNumSearchResultsInTable = '%s записи(ей) в таблице <i>%s</i>';
$strNumSearchResultsTotal = '<b>Итого:</b> <i>%s</i> записи(ей)';
$strNumTables = 'Таблиц';

$strOK = 'Готово';
$strOperations = 'Операции';
$strOperator = 'Оператор';
$strOptimizeTable = 'Оптимизировать таблицу';
$strOr = 'Или';
$strOverhead = 'Накладные расходы';
$strOverwriteExisting = 'Перезаписать существующий(е) файл(ы)';

$strPHP40203 = 'Вы используете версию PHP 4.2.3, которая содержит серьезные ошибки при работе с много-байтовыми строками (mbstring). Смотрите PHP bug report 19404. Данная версия PHP не рекомендуется для использования с phpMyAdmin.';
$strPHPVersion = 'Версия PHP';
$strPageNumber = 'Номер страницы:';
$strPaperSize = 'Размер бумаги';
$strPartialText = 'Частичные тексты';
$strPassword = 'Пароль';
$strPasswordChanged = 'Пароль для %s был успешно изменён.';
$strPasswordEmpty = 'Пустой пароль!';
$strPasswordNotSame = 'Пароли не одинаковы!';
$strPdfDbSchema = 'Структура базы "%s" - страница %s';
$strPdfInvalidTblName = 'Таблица "%s" не существует!';
$strPdfNoTables = 'Нет таблиц';
$strPerHour = 'в час';
$strPerMinute = 'в минуту';
$strPerSecond = 'в секунду';
$strPhoneBook = 'телефонная книга';
$strPhp = 'Создать PHP-код';
$strPmaDocumentation = 'Документация по phpMyAdmin';
$strPmaUriError = 'Директива <tt>$cfg[\'PmaAbsoluteUri\']</tt> должна быть установлена в Вашем конфигурационном файле!';
$strPolish = 'Польский';
$strPortrait = 'Портрет';
$strPos1 = 'Начало';
$strPrevious = 'Назад';
$strPrimary = 'Первичный';
$strPrimaryKeyHasBeenDropped = 'Первичный ключ был удален';
$strPrimaryKeyName = 'Имя первичного ключа должно быть PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>должно</b> быть признаком <b>только</b> первичного ключа!)';
$strPrint = 'Печать';
$strPrintView = 'Версия для печати';
$strPrintViewFull = 'Распечатать (со всем текстом)';
$strPrivDescAllPrivileges = 'Includes all privileges except GRANT.';
$strPrivDescAlter = 'Позволяет изменение структуры существующих таблиц.';
$strPrivDescCreateDb = 'Позволяет создание новых баз данных и таблиц.';
$strPrivDescCreateTbl = 'Позволяет создание новых таблиц.';
$strPrivDescCreateTmpTable = 'Позволяет создание временных таблиц.';
$strPrivDescDelete = 'Позволяет удаление данных.';
$strPrivDescDropDb = 'Позволяет удаление ';
$strPrivDescDropTbl = 'Позволяет удаление таблиц.';
$strPrivDescExecute = 'Позволяет запуск хранимых процедур; Не работает в этой версии MySQL.';
$strPrivDescFile = 'Позволяет импортирование и экспортирование данных в файлы.';
$strPrivDescGrant = 'Позволяет добавление пользователей и привилегий без перезагрузки таблиц привилегий.';
$strPrivDescIndex = 'Позволяет создание и удаление индексов.';
$strPrivDescInsert = 'Позволяет вставку и замену данных.';
$strPrivDescLockTables = 'Позволяет блокировку таблиц для текущего потока.';
$strPrivDescMaxConnections = 'Ограничивает количество соединений, которые пользователь может открыть в течение часа.';
$strPrivDescMaxQuestions = 'Ограничивает количество запросов, которые пользователь может отравит в течение часа.';
$strPrivDescMaxUpdates = 'Ограничивает количество команд, изменяющих любую таблицу или базу данных, которые пользователь может выполнить за час.';
$strPrivDescProcess3 = 'Позволяет убивать процессы других пользоваетелей.';
$strPrivDescProcess4 = 'Позволяет просмотр полных запросов в списке процессов.';
$strPrivDescReferences = 'Не работает в этой версии MySQL.';
$strPrivDescReload = 'Позволяет перезагрузку настроек сервера и очистку его кэшей.';
$strPrivDescReplClient = 'Даёт пользователю право спрашивать где находяться slaves / masters.';
$strPrivDescReplSlave = 'Нужен для репликации slaves.';
$strPrivDescSelect = 'Позволяет чтение данных.';
$strPrivDescShowDb = 'Даёт доступ к полному списку баз данных.';
$strPrivDescShutdown = 'Позволяет остановку сервера.';
$strPrivDescSuper = 'Позволяет соединяться, даже если достигнуто максимальное количество соединений; Необходимо для большинства административных задач, таких как установка глобальных переменных или остановка процессов других пользователей.';
$strPrivDescUpdate = 'Позволяет изменение данных.';
$strPrivDescUsage = 'Нет привилегий.';
$strPrivileges = 'Привилегии';
$strPrivilegesReloaded = 'Привилегии были успешно перезагружены.';
$strProcesslist = 'Список процессов';
$strPutColNames = 'Укажите наименования полей в первой строке';

$strQBE = 'Запрос&nbsp;по&nbsp;примеру';
$strQBEDel = 'Удалить';
$strQBEIns = 'Вставить';
$strQueryFrame = 'Окно запроса';
$strQueryOnDb = 'SQL-запрос БД <b>%s</b>:';
$strQuerySQLHistory = 'История SQL';
$strQueryStatistics = '<b>Статистика запросов</b>: Со времени запуска %s запросов было послано на сервер.';
$strQueryTime = 'Запрос занял %01.4f сек';
$strQueryType = 'Тип запроса';
$strQueryWindowLock = 'Не перезаписывать этот запрос вне окна';

$strReType = 'Подтверждение';
$strReceived = 'Принято';
$strRecords = 'Записи';
$strReferentialIntegrity = 'Проверить целостность данных:';
$strRefresh = 'Обновить';
$strRelationNotWorking = 'Дополнительные возможности для работы со связанными таблицами недоступны. Для определения причины нажмите %sсюда%s.';
$strRelationView = 'Связанный вид';
$strRelationalSchema = 'Реляционная схема';
$strRelations = 'Связи';
$strRelationsForTable = 'Соотношения в таблице';
$strReloadMySQL = 'Перезагрузить MySQL';
$strReloadingThePrivileges = 'Перезагрузка привилегий';
$strRemoveSelectedUsers = 'Удалить выделенных пользователей';
$strRenameDatabaseOK = 'База данных %s переименована в %s';
$strRenameTable = 'Переименовать таблицу в';
$strRenameTableOK = 'Таблица %s была переименована в %s';
$strRepairTable = 'Починить таблицу';
$strReplaceNULLBy = 'Заменить NULL на';
$strReplaceTable = 'Заместить данные таблицы данными из файла';
$strReset = 'Переустановить';
$strResourceLimits = 'Предел ресурсов';
$strRevoke = 'Отменить';
$strRevokeAndDelete = 'Отменить все активные привилегии пользователей и затем удалить их.';
$strRevokeAndDeleteDescr = 'Пользователи всё ещё будут иметь USAGE привилегии до перезагрузки привилегий.';
$strRevokeMessage = 'Вы изменили привилегии для %s';
$strRomanian = 'Румынский';
$strRowLength = 'Длина ряда';
$strRowSize = ' Размер ряда ';
$strRows = 'Ряды';
$strRowsFrom = 'рядов от';
$strRowsModeFlippedHorizontal = 'горизонтально(повёрнутые заголовки)';
$strRowsModeHorizontal = 'горизонтальном';
$strRowsModeOptions = 'в %s режиме, заголовки после каждых %s ячеек';
$strRowsModeVertical = 'вертикальном';
$strRowsStatistic = 'Статистика ряда';
$strRunQuery = 'Выполнить Запрос';
$strRunSQLQuery = 'Выполнить SQL запрос(ы) на БД %ы';
$strRunning = 'на %s';
$strRussian = 'Русский';

$strSQL = 'SQL';
$strSQLExportType = 'Тип экспорта';
$strSQLOptions = 'Опции SQL';
$strSQLParserBugMessage = 'Возможно у Вас ошибка в SQL-парсере. Пожалуйста, проверьте внимательно Ваш запрос и соответствие кавычек. Возможно также, что Вы пытаетесь закачать бинарный файл вне поля quoted text area. Вы можете попробовать выполнить свой запрос через интерфейс командной строки MySQL. Описание ошибки MySQL сервера дано ниже, возможно оно поможет понять, что же произошло. Если у Вас все равно возникают проблемы или если парсер выдает ошибки там, где интерфейс командной строки работает успешно, попробуйте изменить свой SQL запрос до простых запросов и определить, какой именно вызывает проблемы. Вы можете также прислать отчет об ошибке вместе с блоком данных (секция CUT):';
$strSQLParserUserError = 'Кажется возникла ошибка в Вашем SQL запросе. Описание ошибки от MySQL сервера дано ниже, возможно, оно поможет Вам разобраться';
$strSQLQuery = 'SQL-запрос';
$strSQLResult = 'SQL-результат';
$strSQPBugInvalidIdentifer = 'Неправильный идентификатор';
$strSQPBugUnclosedQuote = 'Незакрытая кавычка';
$strSQPBugUnknownPunctuation = 'Неизвестная строка с пунктуацией';
$strSave = 'Сохранить';
$strSaveOnServer = 'Сохранить на сервере в директории %s';
$strScaleFactorSmall = 'Масштаб слишком маленький для отображения всей таблицы на одной странице';
$strSearch = 'Искать';
$strSearchFormTitle = 'Искать в базе данных';
$strSearchInTables = 'В таблице(ах):';
$strSearchNeedle = 'Слово(а) или значение(я) для поиска (включая "%") в:';
$strSearchOption1 = 'хоть одно слово';
$strSearchOption2 = 'все слова';
$strSearchOption3 = 'точное соответствие';
$strSearchOption4 = 'регулярное выражение';
$strSearchResultsFor = 'Искать в "<i>%s</i>" %s:';
$strSearchType = 'Искать:';
$strSecretRequired = 'Конфигурационному файлу сейчас нужна секретная фраза (blowfish_secret).';
$strSelectADb = 'Выберите БД';
$strSelectAll = 'Отметить все';
$strSelectFields = 'Выбрать поля (минимум одно):';
$strSelectNumRows = 'по запросу';
$strSelectTables = 'Выберите таблицу(ы)';
$strSend = 'послать';
$strSent = 'Послано';
$strServer = 'Сервер';
$strServerChoice = 'Выбор сервера';
$strServerNotResponding = 'Сервер не отвечает';
$strServerStatus = 'Текущая информация';
$strServerStatusUptime = 'Этот MySQL сервер работает %s. Он был запущен %s.';
$strServerTabProcesslist = 'Процессы';
$strServerTabVariables = 'Переменные';
$strServerTrafficNotes = '<b>Трафик</b>: Эти таблицы показывают статистику по сетевому трафику MySQL сервера со времени его запуска.';
$strServerVars = 'Переменные и настройки сервера';
$strServerVersion = 'Версия сервера';
$strSessionValue = 'Значение сессии';
$strSetEnumVal = 'Для типов поля "enum" и "set", введите значения по этому формату: \'a\',\'b\',\'c\'...<br />Если вам понадобиться ввести обратную косую черту ("\"") или одиночную кавычку ("\'") среди этих значений, поставьте перед ними обратную косую черту (например, \'\\\\xyz\' или \'a\\\'b\').';
$strShow = 'Показать';
$strShowAll = 'Показать все';
$strShowColor = 'Показать цвет';
$strShowDatadictAs = 'Формат словаря данных';
$strShowFullQueries = 'Показывать Полные Запросы';
$strShowGrid = 'Показать сетку';
$strShowPHPInfo = 'Показать информацию о PHP';
$strShowTableDimension = 'Показать размерность таблицы';
$strShowTables = 'Показать таблицы';
$strShowThisQuery = ' Показать данный запрос снова ';
$strShowingRecords = 'Показывает записи ';
$strSimplifiedChinese = 'Упрощённый китайский';
$strSingly = '(отдельно)';
$strSize = 'Размер';
$strSlovak = 'Словацкий';
$strSlovenian = 'Словенский';
$strSort = 'Отсортировать';
$strSortByKey = 'Сортировать по ключу';
$strSpaceUsage = 'Используемое пространство';
$strSpanish = 'Испанский';
$strSplitWordsWithSpace = 'Слова, разделенные пробелом (" ").';
$strStatCheckTime = 'Последняя проверка';
$strStatCreateTime = 'Создание';
$strStatUpdateTime = 'Последнее обновление';
$strStatement = 'Выражения';
$strStatus = 'Статус';
$strStrucCSV = 'CSV данные';
$strStrucData = 'Структура и данные';
$strStrucDrop = 'Добавить удаление таблицы';
$strStrucExcelCSV = 'CSV для данных MS Excel';
$strStrucNativeExcel = 'Данные из MS Excel';
$strStrucOnly = 'Только структуру';
$strStructPropose = 'Предлагаемая структура таблицы';
$strStructure = 'Структура';
$strSubmit = 'Выполнить';
$strSuccess = 'Ваш SQL-запрос был успешно выполнен';
$strSum = 'Всего';
$strSwedish = 'Шведский';
$strSwitchToTable = 'Переключиться на скопированную таблицу';

$strTable = 'таблица ';
$strTableComments = 'Комментарий к таблице';
$strTableEmpty = 'Пустое название таблицы!';
$strTableHasBeenDropped = 'Таблица %s была удалена';
$strTableHasBeenEmptied = 'Таблица %s была очищена';
$strTableHasBeenFlushed = 'Был сброшен кэш таблицы %s';
$strTableMaintenance = 'Обслуживание таблицы';
$strTableOfContents = 'Оглавление';
$strTableOptions = 'Опции таблицы';
$strTableStructure = 'Структура таблицы';
$strTableType = 'Тип таблицы';
$strTables = '%s таблиц(ы)';
$strTakeIt = 'обработать';
$strTblPrivileges = ' Привилегии, специфичные для таблицы';
$strTextAreaLength = ' Из-за большой длины,<br /> это поле не может быть отредактированно ';
$strThai = 'Таи';
$strTheme = 'Тема / Стиль';
$strThisHost = 'Этот хост';
$strThisNotDirectory = 'Это была не директория';
$strThreadSuccessfullyKilled = 'Thread %s был удален.';
$strTime = 'Время';
$strToggleScratchboard = 'toggle scratchboard';
$strTotal = 'всего';
$strTotalUC = 'Всего';
$strTraditionalChinese = 'Традиционный китайский';
$strTraditionalSpanish = 'Традиционный Испанский';
$strTraffic = 'Трафик';
$strTransformation_application_octetstream__download = 'Показать линк к загрузке бинарных данных полей. Первый вариант: укажите имя бинарного файла. Второй вариант: укажите возможное имя строки таблицы в которой находится бинарный файл. Если вы выберете второй вариант, убедитесь в том, что имя бинарного файла  в первом варианте не указанно';
$strTransformation_image_jpeg__inline = 'Отображает предпросмотр, на который можно кликнуть; опции: ширина,высота в пикселах (сохраняет исходный масштаб)';
$strTransformation_image_jpeg__link = 'Отображает ссылку на это изображение(direct blob download, i.e.).';
$strTransformation_image_png__inline = 'See image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Берёт поле TIME, TIMESTAMP или DATETIME и форматирует его в соответствии с вашим локальным форматом даты. Первая опция - это сдвиг (в часах), который будет добавлен к timestamp (По умолчанию: 0). Вторая опция - это другой формат даты в соответствии с параметрами, доступными для функции PHP strftime().';
$strTransformation_text_plain__external = 'ТОЛЬКО LINUX: Запускает внешнее приложение и запоняет поля через стандартный ввод. Возвращает стандартный вывод приложения. По умолчанию Tidy, для форматирования HTML кода. По соображениям безопасности, вы должны вручную отредактировать файл libraries/transformations/text_plain__external.inc.php и вписать программы, которые вы хотите запускать. Первая опция - это номер программы, которую вы хотите использовать, вторая - параметры для программы. Третий параметр при значении 1 будет конвертировать вывод, используя htmlspecialchars() (По умолчанию 1). Четвёртый параметр при значении 1 выставит NOWRAP, так что весь вывод будет отображён без переформатирования (По умолчанию 1)';
$strTransformation_text_plain__formatted = 'Сохраняет исходное форматирование поля. Экранирование не производится.';
$strTransformation_text_plain__imagelink = 'Показывает изображение и ссылку, поле содержит имя файла; первая опция - это префикс вроде "http://domain.com/", вторая - ширина в пикселах, третья - высота.';
$strTransformation_text_plain__link = 'Отображает ссылку, поле содержит имя файла; первая опция - это префикс вроде "http://domain.com/", вторая - заголовок для ссылки.';
$strTransformation_text_plain__substr = 'Показывает только часть строки. Первая опция - это сдвиг, определяющий где начинается вывод текста (По умолчанию 0). Вторая опция - это количество возвращаемого текста. Если не определено, то возвращается весь остающийся текст. Третья опция определяет символы, которые будут добавлены к выводу, когда возвращается подстрока. (По умолчанию: ...) .';
$strTruncateQueries = 'Обрезать Показанные Запросы';
$strTurkish = 'Турецкий';
$strType = 'Тип';

$strUkrainian = 'Украинский';
$strUncheckAll = 'Снять отметку со всех';
$strUnicode = 'Юникод';
$strUnique = 'Уникальное';
$strUnknown = 'неизвестно';
$strUnselectAll = 'Снять отметку со всех';
$strUpdComTab = 'Пожалуйста, посмотрите как обновить Column_comments Таблицу в документации';
$strUpdatePrivMessage = 'Были изменены привилегии для';
$strUpdateProfileMessage = 'Профиль был обновлен.';
$strUpdateQuery = 'Дополнить запрос';
$strUpgrade = 'Вы должны обновить %s до версии %s или выше.';
$strUsage = 'Использование';
$strUseBackquotes = 'Обратные кавычки в названиях таблиц и полей';
$strUseHostTable = 'Использовать таблицу хостов';
$strUseTables = 'Использовать таблицы';
$strUseTextField = 'Использовать текстовое поле';
$strUseThisValue = 'Использовать это значение';
$strUser = 'Пользователь';
$strUserAlreadyExists = 'Пользователь %s уже существует!';
$strUserEmpty = 'Пустое имя пользователя!';
$strUserName = 'Имя пользователя';
$strUserNotFound = 'Выделенный пользователь не был найден в таблице привилегий.';
$strUserOverview = 'User overview';
$strUsersDeleted = 'Выбранные пользователи были успешно удалены.';
$strUsersHavingAccessToDb = 'Пользователи с правами доступа к &quot;%s&quot;';

$strValidateSQL = 'Проверить SQL';
$strValidatorError = 'Проверка SQL не может быть инициализирована. Проверьте, установлены ли необходимые модули расширений для PHP, описанные в %sдокументации%s.';
$strValue = 'Значение';
$strVar = 'Переменная';
$strViewDump = 'Просмотреть дамп таблицы';
$strViewDumpDB = 'Просмотреть дамп БД';
$strViewDumpDatabases = 'Просмотреть дамп (схему) БД';

$strWebServerUploadDirectory = 'директория, куда помещаются закачанные файлы от web-сервера';
$strWebServerUploadDirectoryError = 'директория, которую Вы установили как "upload" не может быть открыта';
$strWelcome = 'Добро пожаловать в %s';
$strWestEuropean = 'Западно-Европейский';
$strWildcard = 'шаблон';
$strWindowNotFound = 'Целевое окно браузера не может быть обновлено. Возможно, вы закрыли родительское окно или ваш браузер блокирует межоконные обновления из-за настроек безопасности';
$strWithChecked = 'С отмеченными:';
$strWritingCommentNotPossible = 'Написание комментария невозможно';
$strWritingRelationNotPossible = 'Добавление связи невозможно';
$strWrongUser = 'Ошибочный логин/пароль. В доступе отказано.';

$strXML = 'XML';

$strYes = 'Да';

$strZeroRemovesTheLimit = 'Замечание: Установка этих опций в  0 (ноль) удаляет лимит.';
$strZip = 'архивировать в zip';

$strPersian = 'Persian';  //to translate
$strAddFields = 'Add %s field(s)';  //to translate
$strNoThemeSupport = 'No themes support, please check your configuration and/or your themes in directory %s.';  //to translate
$strUseTabKey = 'Use TAB key to move from value to value, or CTRL+arrows to move anywhere';  //to translate
$strEscapeWildcards = 'Wildcards _ and % should be escaped with a \ to use them literally';  //to translate
$strBinLogName = 'Log name';  //to translate
$strBinLogPosition = 'Position';  //to translate
$strBinLogEventType = 'Event type';  //to translate
$strBinLogServerId = 'Server ID';  //to translate
$strBinLogOriginalPosition = 'Original position';  //to translate
$strBinLogInfo = 'Information';  //to translate
$strBinaryLog = 'Binary log';  //to translate
$strSelectBinaryLog = 'Select binary log to view';  //to translate
$strDBCopy = 'Copy database to';  //to translate
$strCopyDatabaseOK = 'Database %s has been copied to %s';  //to translate
$strSwitchToDatabase = 'Switch to copied database';  //to translate
$strPasswordHashing = 'Password Hashing';  //to translate
$strCompatibleHashing = 'MySQL&nbsp;4.0 compatible';  //to translate
$strIndexWarningPrimary = 'PRIMARY and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningUnique = 'UNIQUE and INDEX keys should not both be set for column `%s`';//to translate
$strIndexWarningMultiple = 'More than one %s key was created for column `%s`';//to translate
$strIndexWarningTable = 'Problems with indexes of table `%s`';//to translate
$strNoActivity = 'No activity since %s seconds or more, please login again';  //to translate
$strApproximateCount = 'May be approximate. See FAQ 3.11';  //to translate
$strSQLExportCompatibility = 'SQL export compatibility';  //to translate
$strMbOverloadWarning = 'You have enabled mbstring.func_overload in your PHP configuration. This option is incompatible with phpMyAdmin and might cause breaking of some data!';  //to translate
$strMbExtensionMissing = 'The mbstring PHP extension was not found and you seem to be using multibyte charset. Without mbstring extension phpMyAdmin is unable to split strings correctly and it may result in unexpected results.';  //to translate
$strAfterInsertNext = 'Edit next row';  //to translate
$strView = 'View';  //to translate
$strViewHasBeenDropped = 'View %s has been dropped';  //to translate
$strEngines = 'Engines';  //to translate
$strStorageEngines = 'Storage Engines';  //to translate
$strStorageEngine = 'Storage Engine';  //to translate
$strNoDetailsForEngine = 'There is no detailed status information available for this storage engine.';  //to translate
$strDefaultEngine = '%s is the default storage engine on this MySQL server.';  //to translate
$strEngineAvailable = '%s is available on this MySQL server.';  //to translate
$strEngineUnsupported = 'This MySQL server does not support the %s storage engine.';  //to translate
$strEngineDisabled = '%s has been disabled for this MySQL server.';  //to translate
$strMyISAMSortBufferSize = 'Sort buffer size';  //to translate
$strMyISAMSortBufferSizeDesc = 'The buffer that is allocated when sorting MyISAM indexes during a REPAIR TABLE or when creating indexes with CREATE INDEX or ALTER TABLE.';  //to translate
$strMyISAMDataPointerSize = 'Data pointer size';  //to translate
$strMyISAMDataPointerSizeDesc = 'The default pointer size in bytes, to be used by CREATE TABLE for MyISAM tables when no MAX_ROWS option is specified.';  //to translate
$strMyISAMRecoverOptions = 'Automatic recovery mode';  //to translate
$strMyISAMRecoverOptionsDesc = 'The mode for automatic recovery of crashed MyISAM tables, as set via the --myisam-recover server startup option.';  //to translate
$strMyISAMRepairThreads = 'Repair threads';  //to translate
$strMyISAMRepairThreadsDesc = 'If this value is greater than 1, MyISAM table indexes are created in parallel (each index in its own thread) during the Repair by sorting process.';  //to translate
$strMyISAMMaxSortFileSize = 'Maximum size for temporary sort files';  //to translate
$strMyISAMMaxSortFileSizeDesc = 'The maximum size of the temporary file MySQL is allowed to use while re-creating a MyISAM index (during REPAIR TABLE, ALTER TABLE, or LOAD DATA INFILE).';  //to translate
$strMyISAMMaxExtraSortFileSize = 'Maximum size for temporary files on index creation';  //to translate
$strMyISAMMaxExtraSortFileSizeDesc = 'If the temporary file used for fast MyISAM index creation would be larger than using the key cache by the amount specified here, prefer the key cache method.';  //to translate
$strLongOperation = 'This operation could be long. Proceed anyway?';  //to translate
$strVersionInformation = 'Version information';  //to translate
$strInnoDBDataHomeDir = 'Data home directory';  //to translate
$strInnoDBDataHomeDirDesc = 'The common part of the directory path for all InnoDB data files.';  //to translate
$strInnoDBDataFilePath = 'Data files';  //to translate
$strInnoDBAutoextendIncrement = 'Autoextend increment';  //to translate
$strInnoDBAutoextendIncrementDesc = ' The increment size for extending the size of an autoextending tablespace when it becomes full.';  //to translate
$strBufferPool = 'Buffer Pool';  //to translate
$strBufferPoolUsage = 'Buffer Pool Usage';  //to translate
$strDataPages = 'Pages containing data';  //to translate
$strFreePages = 'Free pages';  //to translate
$strBusyPages = 'Busy pages';  //to translate
$strDirtyPages = 'Dirty pages';  //to translate
$strPagesToBeFlushed = 'Pages to be flushed';  //to translate
$strLatchedPages = 'Latched pages';  //to translate
$strBufferPoolActivity = 'Buffer Pool Activity';  //to translate
$strReadRequests = 'Read requests';  //to translate
$strWriteRequests = 'Write requests';  //to translate
$strBufferReadMisses = 'Read misses';  //to translate
$strBufferReadMissesInPercent = 'Read misses in %';  //to translate
$strBufferWriteWaits = 'Write waits';  //to translate
$strBufferWriteWaitsInPercent = 'Write waits in %';  //to translate
$strHTMLExcel = 'Microsoft Excel 2000';  //to translate
$strHTMLExcelOptions = 'Microsoft Excel 2000 export options';  //to translate
$strHTMLWord = 'Microsoft Word 2000';  //to translate
$strHTMLWordOptions = 'Microsoft Word 2000 export options';  //to translate
$strInnoDBBufferPoolSizeDesc = 'The size of the memory buffer InnoDB uses to cache data and indexes of its tables.';  //to translate
$strInnoDBBufferPoolSize = 'Buffer pool size';  //to translate
$strInnoDBPages = 'pages';  //to translate
$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate

$strPrivDescCreateView = 'Allows creating new views.';  //to translate
$strPrivDescCreateUser = 'Allows creating, dropping and renaming user accounts.';  //to translate
$strPrivDescCreateRoutine = 'Allows creating stored routines.';  //to translate
$strPrivDescAlterRoutine = 'Allows altering and dropping stored routines.';  //to translate
$strPrivDescShowView = 'Allows performing SHOW CREATE VIEW queries.';  //to translate
$strPrivDescExecute5 = 'Allows executing stored routines.';  //to translate
$strCreateDatabaseBeforeCopying = 'CREATE DATABASE before copying';  //to translate
$strGeneratePassword = 'Generate Password';  //to translate
$strGenerate = 'Generate';  //to translate
$strCopy = 'Copy';  //to translate
$strTransformation_application_octetstream__hex = 'Displays hexadecimal representation of data.';  //to translate
$strInvalidFieldCount = 'Table must have at least one field.';  //to translate
$strInvalidRowNumber = '%d is not valid row number.';  //to translate
$strInvalidColumnCount = 'Column count has to be larger than zero.';  //to translate
$strInvalidFieldAddCount = 'You have to add at least one field.';  //to translate
$strAndThen = 'and then';  //to translate
$strInvalidAuthMethod = 'Invalid authentication method set in configuration:';  //to translate
$strRunSQLQueryOnServer = 'Run SQL query/queries on server %s';  //to translate
$strCSV = 'CSV';  //to translate
$strImport = 'Import';  //to translate
$strImportFormat = 'Format of imported file';  //to translate
$strFileToImport = 'File to import';  //to translate
$strCompressionWillBeDetected = 'Imported file compression will be automatically detected from: %s';  //to translate
$strCanNotLoadImportPlugins = 'Could not load import plugins, please check your installation!';  //to translate
$strCSVImportOptions = 'CSV options';  //to translate
$strPartialImport = 'Partial import';  //to translate
$strAllowInterrupt = 'Allow interrupt of import in case script detects it is close to time limit. This might be good way to import large files, however it can break transactions.';  //to translate
$strTimeoutPassed = 'Script timeout passed, if you want to finish import, please resubmit same file and import will resume.';  //to translate
$strTimeoutNothingParsed = 'However on last run no data has been parsed, this usually means phpMyAdmin won\'t be able to finish this import unless you increase php time limits.';  //to translate
$strTimeoutInfo = 'Previous import timed out, after resubmitting will continue from position %d.';  //to translate
$strUnsupportedCompressionDetected = 'You attempted to load file with unsupported compression (%s). Either support for it is not implemented or disabled by your configuration.';  //to translate
$strNothingToImport = 'You didn\'t enter any data to import!';  //to translate
$strIgnoreDuplicates = 'Ignore duplicate rows';  //to translate
$strSkipQueries = 'Number of records(queries) to skip from start';  //to translate
$strInvalidColumn = 'Invalid column (%s) specified!';  //to translate
$strNoFilesFoundInZip = 'No files found inside ZIP archive!';  //to translate
$strErrorInZipFile = 'Error in ZIP archive:';  //to translate
$strFlushQueryCache = 'Flush query cache';  //to translate
$strFlushTables = 'Flush (close) all tables';  //to translate
$strHandler = 'Handler';  //to translate
$strJoins = 'Joins';  //to translate
$strKeyCache = 'Key cache';  //to translate
$strMaxConnects = 'max. concurrent connections';  //to translate
$strQueryCache = 'Query cache';  //to translate
$strReplication = 'Replication';  //to translate
$strServerStatusDelayedInserts = 'Delayed inserts';  //to translate
$strShowOpenTables = 'Show open tables';  //to translate
$strShowSlaveHosts = 'Show slave hosts';  //to translate
$strShowSlaveStatus = 'Show slave status';  //to translate
$strShowStatusReset = 'Reset';  //to translate
$strShowStatusBinlog_cache_disk_useDescr = 'The number of transactions that used the temporary binary log cache but that exceeded the value of binlog_cache_size and used a temporary file to store statements from the transaction.';  //to translate
$strShowStatusBinlog_cache_useDescr = 'The number of transactions that used the temporary binary log cache.';  //to translate
$strShowStatusCreated_tmp_disk_tablesDescr = 'The number of temporary tables on disk created automatically by the server while executing statements. If Created_tmp_disk_tables is big, you may want to increase the tmp_table_size  value to cause temporary tables to be memory-based instead of disk-based.';  //to translate
$strShowStatusCreated_tmp_filesDescr = 'How many temporary files mysqld has created.';  //to translate
$strShowStatusCreated_tmp_tablesDescr = 'The number of in-memory temporary tables created automatically by the server while executing statements.';  //to translate
$strShowStatusDelayed_errorsDescr = 'The number of rows written with INSERT DELAYED for which some error occurred (probably duplicate key).';  //to translate
$strShowStatusDelayed_insert_threadsDescr = 'The number of INSERT DELAYED handler threads in use. Every different table on which one uses INSERT DELAYED gets its own thread.';  //to translate
$strShowStatusDelayed_writesDescr = 'The number of INSERT DELAYED rows written.';  //to translate
$strShowStatusFlush_commandsDescr  = 'The number of executed FLUSH statements.';  //to translate
$strShowStatusHandler_commitDescr = 'The number of internal COMMIT statements.';  //to translate
$strShowStatusHandler_deleteDescr = 'The number of times a row was deleted from a table.';  //to translate
$strShowStatusHandler_discoverDescr = 'The MySQL server can ask the NDB Cluster storage engine if it knows about a table with a given name. This is called discovery. Handler_discover indicates the number of time tables have been discovered.';  //to translate
$strShowStatusHandler_read_firstDescr = 'The number of times the first entry was read from an index. If this is high, it suggests that the server is doing a lot of full index scans; for example, SELECT col1 FROM foo, assuming that col1 is indexed.';  //to translate
$strShowStatusHandler_read_keyDescr = 'The number of requests to read a row based on a key. If this is high, it is a good indication that your queries and tables are properly indexed.';  //to translate
$strShowStatusHandler_read_nextDescr = 'The number of requests to read the next row in key order. This is incremented if you are querying an index column with a range constraint or if you are doing an index scan.';  //to translate
$strShowStatusHandler_read_prevDescr = 'The number of requests to read the previous row in key order. This read method is mainly used to optimize ORDER BY ... DESC.';  //to translate
$strShowStatusHandler_read_rndDescr = 'The number of requests to read a row based on a fixed position. This is high if you are doing a lot of queries that require sorting of the result. You probably have a lot of queries that require MySQL to scan whole tables or you have joins that don\'t use keys properly.';  //to translate
$strShowStatusHandler_read_rnd_nextDescr = 'The number of requests to read the next row in the data file. This is high if you are doing a lot of table scans. Generally this suggests that your tables are not properly indexed or that your queries are not written to take advantage of the indexes you have.';  //to translate
$strShowStatusHandler_rollbackDescr = 'The number of internal ROLLBACK statements.';  //to translate
$strShowStatusHandler_updateDescr = 'The number of requests to update a row in a table.';  //to translate
$strShowStatusHandler_writeDescr = 'The number of requests to insert a row in a table.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'The number of pages containing data (dirty or clean).';  //to translate
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'The number of pages currently dirty.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'The number of buffer pool pages that have been requested to be flushed.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'The number of free pages.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'The number of latched pages in InnoDB buffer pool. These are pages currently being read or written or that can\'t be flushed or removed for some other reason.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'The number of pages busy because they have been allocated for administrative overhead such as row locks or the adaptive hash index. This value can also be calculated as Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';  //to translate
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Total size of buffer pool, in pages.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'The number of "random" read-aheads InnoDB initiated. This happens when a query is to scan a large portion of a table but in random order.';  //to translate
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'The number of sequential read-aheads InnoDB initiated. This happens when InnoDB does a sequential full table scan.';  //to translate
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'The number of logical read requests InnoDB has done.';  //to translate
$strShowStatusInnodb_buffer_pool_readsDescr = 'The number of logical reads that InnoDB could not satisfy from buffer pool and had to do a single-page read.';  //to translate
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normally, writes to the InnoDB buffer pool happen in the background. However, if it\'s necessary to read or create a page and no clean pages are available, it\'s necessary to wait for pages to be flushed first. This counter counts instances of these waits. If the buffer pool size was set properly, this value should be small.';  //to translate
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'The number writes done to the InnoDB buffer pool.';  //to translate
$strShowStatusInnodb_data_fsyncsDescr = 'The number of fsync() operations so far.';  //to translate
$strShowStatusInnodb_data_pending_fsyncsDescr = 'The current number of pending fsync() operations.';  //to translate
$strShowStatusInnodb_data_pending_readsDescr = 'The current number of pending reads.';  //to translate
$strShowStatusInnodb_data_pending_writesDescr = 'The current number of pending writes.';  //to translate
$strShowStatusInnodb_data_readDescr = 'The amount of data read so far, in bytes.';  //to translate
$strShowStatusInnodb_data_readsDescr = 'The total number of data reads.';  //to translate
$strShowStatusInnodb_data_writesDescr = 'The total number of data writes.';  //to translate
$strShowStatusInnodb_data_writtenDescr = 'The amount of data written so far, in bytes.';  //to translate
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_dblwr_writesDescr = 'The number of doublewrite writes that have been performed and the number of pages that have been written for this purpose.';  //to translate
$strShowStatusInnodb_log_waitsDescr = 'The number of waits we had because log buffer was too small and we had to wait for it to be flushed before continuing.';  //to translate
$strShowStatusInnodb_log_write_requestsDescr = 'The number of log write requests.';  //to translate
$strShowStatusInnodb_log_writesDescr = 'The number of physical writes to the log file.';  //to translate
$strShowStatusInnodb_os_log_fsyncsDescr = 'The number of fsyncs writes done to the log file.';  //to translate
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'The number of pending log file fsyncs.';  //to translate
$strShowStatusInnodb_os_log_pending_writesDescr = 'Pending log file writes.';  //to translate
$strShowStatusInnodb_os_log_writtenDescr = 'The number of bytes written to the log file.';  //to translate
$strShowStatusInnodb_page_sizeDescr = 'The compiled-in InnoDB page size (default 16KB). Many values are counted in pages; the page size allows them to be easily converted to bytes.';  //to translate
$strShowStatusInnodb_pages_createdDescr = 'The number of pages created.';  //to translate
$strShowStatusInnodb_pages_readDescr = 'The number of pages read.';  //to translate
$strShowStatusInnodb_pages_writtenDescr = 'The number of pages written.';  //to translate
$strShowStatusInnodb_row_lock_current_waitsDescr = 'The number of row locks currently being waited for.';  //to translate
$strShowStatusInnodb_row_lock_timeDescr = 'The total time spent in acquiring row locks, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_avgDescr = 'The average time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_time_maxDescr = 'The maximum time to acquire a row lock, in milliseconds.';  //to translate
$strShowStatusInnodb_row_lock_waitsDescr = 'The number of times a row lock had to be waited for.';  //to translate
$strShowStatusInnodb_rows_deletedDescr = 'The number of rows deleted from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_insertedDescr = 'The number of rows inserted in InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_readDescr = 'The number of rows read from InnoDB tables.';  //to translate
$strShowStatusInnodb_rows_updatedDescr = 'The number of rows updated in InnoDB tables.';  //to translate
$strShowStatusKey_blocks_not_flushedDescr = 'The number of key blocks in the key cache that have changed but haven\'t yet been flushed to disk. It used to be known as Not_flushed_key_blocks.';  //to translate
$strShowStatusKey_blocks_unusedDescr = 'The number of unused blocks in the key cache. You can use this value to determine how much of the key cache is in use.';  //to translate
$strShowStatusKey_blocks_usedDescr = 'The number of used blocks in the key cache. This value is a high-water mark that indicates the maximum number of blocks that have ever been in use at one time.';  //to translate
$strShowStatusKey_read_requestsDescr = 'The number of requests to read a key block from the cache.';  //to translate
$strShowStatusKey_readsDescr = 'The number of physical reads of a key block from disk. If Key_reads is big, then your key_buffer_size value is probably too small. The cache miss rate can be calculated as Key_reads/Key_read_requests.';  //to translate
$strShowStatusKey_write_requestsDescr = 'The number of requests to write a key block to the cache.';  //to translate
$strShowStatusKey_writesDescr = 'The number of physical writes of a key block to disk.';  //to translate
$strShowStatusLast_query_costDescr = 'The total cost of the last compiled query as computed by the query optimizer. Useful for comparing the cost of different query plans for the same query. The default value of 0 means that no query has been compiled yet.';  //to translate
$strShowStatusNot_flushed_delayed_rowsDescr = 'The number of rows waiting to be written in INSERT DELAY queues.';  //to translate
$strShowStatusOpen_filesDescr = 'The number of files that are open.';  //to translate
$strShowStatusOpen_streamsDescr = 'The number of streams that are open (used mainly for logging).';  //to translate
$strShowStatusOpen_tablesDescr = 'The number of tables that are open.';  //to translate
$strShowStatusOpened_tablesDescr = 'The number of tables that have been opened. If opened tables is big, your table cache value is probably too small.';  //to translate
$strShowStatusQcache_free_blocksDescr = 'The number of free memory blocks in query cache.';  //to translate
$strShowStatusQcache_free_memoryDescr = 'The amount of free memory for query cache.';  //to translate
$strShowStatusQcache_hitsDescr = 'The number of cache hits.';  //to translate
$strShowStatusQcache_insertsDescr = 'The number of queries added to the cache.';  //to translate
$strShowStatusQcache_lowmem_prunesDescr = 'The number of queries that have been removed from the cache to free up memory for caching new queries. This information can help you tune the query cache size. The query cache uses a least recently used (LRU) strategy to decide which queries to remove from the cache.';  //to translate
$strShowStatusQcache_not_cachedDescr = 'The number of non-cached queries (not cachable, or not cached due to the query_cache_type setting).';  //to translate
$strShowStatusQcache_queries_in_cacheDescr = 'The number of queries registered in the cache.';  //to translate
$strShowStatusQcache_total_blocksDescr = 'The total number of blocks in the query cache.';  //to translate
$strShowStatusRpl_statusDescr = 'The status of failsafe replication (not yet implemented).';  //to translate
$strShowStatusSelect_full_joinDescr = 'The number of joins that do not use indexes. If this value is not 0, you should carefully check the indexes of your tables.';  //to translate
$strShowStatusSelect_full_range_joinDescr = 'The number of joins that used a range search on a reference table.';  //to translate
$strShowStatusSelect_rangeDescr = 'The number of joins that used ranges on the first table. (It\'s normally not critical even if this is big.)';  //to translate
$strShowStatusSelect_range_checkDescr = 'The number of joins without keys that check for key usage after each row. (If this is not 0, you should carefully check the indexes of your tables.)';  //to translate
$strShowStatusSelect_scanDescr = 'The number of joins that did a full scan of the first table.';  //to translate
$strShowStatusSlave_open_temp_tablesDescr = 'The number of temporary tables currently open by the slave SQL thread.';  //to translate
$strShowStatusSlave_retried_transactionsDescr = 'Total (since startup) number of times the replication slave SQL thread has retried transactions.';  //to translate
$strShowStatusSlave_runningDescr = 'This is ON if this server is a slave that is connected to a master.';  //to translate
$strShowStatusSlow_launch_threadsDescr = 'The number of threads that have taken more than slow_launch_time seconds to create.';  //to translate
$strShowStatusSlow_queriesDescr = 'The number of queries that have taken more than long_query_time seconds.';  //to translate
$strShowStatusSort_merge_passesDescr = 'The number of merge passes the sort algorithm has had to do. If this value is large, you should consider increasing the value of the sort_buffer_size system variable.';  //to translate
$strShowStatusSort_rangeDescr = 'The number of sorts that were done with ranges.';  //to translate
$strShowStatusSort_rowsDescr = 'The number of sorted rows.';  //to translate
$strShowStatusSort_scanDescr = 'The number of sorts that were done by scanning the table.';  //to translate
$strShowStatusTable_locks_immediateDescr = 'The number of times that a table lock was acquired immediately.';  //to translate
$strShowStatusTable_locks_waitedDescr = 'The number of times that a table lock could not be acquired immediately and a wait was needed. If this is high, and you have performance problems, you should first optimize your queries, and then either split your table or tables or use replication.';  //to translate
$strShowStatusThreads_cachedDescr = 'The number of threads in the thread cache. The cache hit rate can be calculated as Threads_created/Connections. If this value is red you should raise your thread_cache_size.';  //to translate
$strShowStatusThreads_connectedDescr = 'The number of currently open connections.';  //to translate
$strShowStatusThreads_createdDescr = 'The number of threads created to handle connections. If Threads_created is big, you may want to increase the thread_cache_size value. (Normally this doesn\'t give a notable performance improvement if you have a good thread implementation.)';  //to translate
$strShowStatusThreads_runningDescr = 'The number of threads that are not sleeping.';  //to translate
$strSorting = 'Sorting';  //to translate
$strTempData = 'Temporary data';  //to translate
$strThreads = 'Threads';  //to translate
$strLDI = 'CSV using LOAD DATA';  //to translate
$strLDILocal = 'Use LOCAL keyword';  //to translate
$strLDIImportOptions = 'Options for CSV import using LOAD DATA';  //to translate
$strInvalidLDIImport = 'This plugin does not support compressed imports!';  //to translate
$strTableAlreadyExists = 'Table %s already exists!';  //to translate
$strTransactionCoordinator = 'Transaction coordinator';  //to translate
$strNumberOfFields = 'Number of fields';  //to translate
$strShowingBookmark = 'Showing bookmark';  //to translate
$strUploadLimit = 'You probably tried to upload too large file. Please refer to %sdocumentation%s for ways to workaround this limit.';  //to translate
$strDeleteNoUsersSelected = 'No users selected for deleting!';  //to translate
$strPrivDescMaxUserConnections = 'Limits the number of simultaneous connections the user may have.';  //to translate
$strMaximalQueryLength = 'Maximal length of created query';  //to translate
$strBookmarkCreated = 'Bookmark %s created';  //to translate
$strBookmarkReplace = 'Replace existing bookmark of same name';  //to translate
$strTransformation_text_plain__sql = 'Formats text as SQL query with syntax highlighting.';  //to translate
$strEsperanto = 'Esperanto';  //to translate
$strInvalidServerIndex = 'Invalid server index: "%s"';  //to translate
$strInvalidServerHostname = 'Invalid hostname for server %1$s. Please review your configuration.';  //to translate
$strFileNameTemplateDescriptionTable = 'table name';  //to translate
$strFileNameTemplateDescriptionDatabase = 'database name';  //to translate
$strFileNameTemplateDescriptionServer = 'server name';  //to translate
$strFileNameTemplateDescription = 'This value is interpreted using %1$sstrftime%2$s, so you can use time formatting strings. Additionally the following transformations will happen: %3$s. Other text will be kept as is.';  //to translate
$strProtocolVersion = 'Protocol version';  //to translate
$strMysqlClientVersion = 'MySQL client version';  //to translate
$strUsedPhpExtensions = 'Used PHP extensions';  //to translate
$strOpenNewWindow = 'Open new phpMyAdmin window';  //to translate
$strLanguageUnknown = 'Unknown language: %1$s.';  //to translate
$strLanguageFileNotFound = 'Language file "%1$s" not found.';  //to translate
$strThemeNoPreviewAvailable = 'No preview available.';  //to translate
$strConfigDefaultFileError = 'Could not load default configuration from: "%1$s"';  //to translate
$strPDF = 'PDF';  //to translate
$strPDFOptions = 'PDF options';  //to translate
$strPDFReportTitle = 'Report title';  //to translate
$strInvalidCSVParameter = 'Invalid parameter for CSV import: %s';  //to translate
$strInvalidCSVFieldCount = 'Invalid field count in CSV input on line %d.';  //to translate
$strInvalidCSVFormat = 'Invalid format of CSV input on line %d.';  //to translate
$strImportSuccessfullyFinished = 'Import has been successfully finished, %d queries executed.';  //to translate
$strThemeNotFound = 'Theme %s not found!';  //to translate
$strThemeDefaultNotFound = 'Default theme %s not found!';  //to translate
$strThemeNoValidImgPath = 'No valid image path for theme %s found!';  //to translate
$strThemePathNotFound = 'Theme path not found for theme %s!';  //to translate
$strAccessDeniedCreateConfig = 'Probably reason of this is that you did not create configuration file. You might want to use %1$ssetup script%2$s to create one.';  //to translate
$strSQLImportOptions = 'SQL options';  //to translate
$strBrowseDistinctValues = 'Browse distinct values';  //to translate
$strStatisticsOverrun = 'On a busy server, the byte counters may overrun, so those statistics as reported by the MySQL server may be incorrect.';  //to translate
$strViewMaxExactCount = 'This view has more than %s rows. Please refer to %sdocumentation%s.';  //to translate
?>
